@@ -70,16 +70,18 @@ define ([
     prototypes
 ) {
 
+    console.log("Entering mfile-www current-user function");
+
     // Initialization routine (run only once but the variables are available
     // to the current-user function and provide storage for the object it
     // returns)
     var cu = Object.create(prototypes.user),
         ce = cf('currentUser'),
-        priv = cf('currentUserPriv') || 'passerby',
+        priv = cf('currentUserPriv'),
         flag1;
 
-    //console.log("current-user: ce is ", ce);
-    //console.log("current-user: currentUserPriv is " + priv);
+    console.log("current-user: ce is ", ce);
+    console.log("current-user: priv is " + priv);
 
     if (ce) {
         $.extend(cu, ce)
@@ -87,10 +89,12 @@ define ([
 
     // current-user function
     return function (sw, arg) { 
+        console.log('current-user function called with arguments ', sw, arg);
         if (sw === 'obj') {
             if (arg) {
                 console.log('NOTICE: setting current user object to ', arg);
                 cu = arg;
+                cf('currentUser', cu);
             }
             console.log('cu.nick is ' + cu.nick);
             return cu.nick ? cu : null;
@@ -99,6 +103,7 @@ define ([
             if (arg) {
                 console.log('NOTICE: setting current user priv to ' + arg);
                 priv = arg;
+                cf('currentUserPriv', priv);
             }
             return priv;
         }
@@ -109,9 +114,6 @@ define ([
             }
             return flag1;
         }
-        if ( ! cf('connectToRestServer')) {
-            return null;
-        }
         return {
             'obj': cu,
             'priv': priv,
